ParagraphNodeSerializeParser class

段落节点序列化处理器

Inheritance

Properties

customAttributionDeserializeBuilder ← AttributionDeserializeBuilder?
no getterinherited
customAttributionSerializeBuilder ← AttributionSerializeBuilder?
no getterinherited
hashCode → int
The hash code for this object.
no setterinherited
keyAttributedText → String
finalinherited
keyAttribution → String
finalinherited
keyAttributionId → String
finalinherited
finalinherited
keyAttributionName → String
finalinherited
keyImageAltText → String
finalinherited
keyImageUrl → String
finalinherited
keyListType → String
finalinherited
keyMetadata → String
finalinherited
keyNodeId → String
finalinherited
keyNodeInfo → String
finalinherited
keyNodeType → String
finalinherited
keySpanOffset → String
finalinherited
keySpans → String
finalinherited
keySpanType → String
finalinherited
keyTaskComplete → String
finalinherited
keyText → String
finalinherited
nodeId → dynamic
快速创建id,Quickly create IDs
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

defaultAttributionDeserializeBuilder(Map<String, dynamic> map) → Attribution?
默认属性反序列化构建器
inherited
defaultAttributionSerializeBuilder(Attribution attribution) → Map<String, dynamic>?
默认属性序列化构建器
inherited
deserialize(Map<String, dynamic> map) → DocumentNode?
Deserialization
inherited
deserializeAttrText(Map<String, dynamic>? map, {AttributionDeserializeBuilder? deserializeBuilder}) → AttributedText
Deserialization AttributedText
inherited
deserializeMetadata(Map<String, dynamic>? metadata, {dynamic covert(String key, dynamic value)?, List<NamedAttribution>? customNameAttribution}) → Map<String, dynamic>
Deserialized Metadata, which encapsulates common types. Custom metadata needs to be converted by covert.
inherited
deserializeNode(Map<String, dynamic> map) → ParagraphNode?
Deserialize the node
override
deserializeSingleColumnLayoutMetadata(Map<String, dynamic> map) → Map<String, dynamic>
inherited
deserializeSpans(List spans, {AttributionDeserializeBuilder? deserializeBuilder}) → AttributedSpans
反序列化AttributedSpans的数据
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(DocumentNode node) → Map<String, dynamic>?
Serialization
inherited
serializeAttrText(AttributedText attributedText, {AttributionSerializeBuilder? serializeBuilder}) → Map<String, dynamic>
Serialize the AttributedText
inherited
serializeMetadata(Map<String, dynamic>? metadata, {dynamic covert(String key, dynamic value)?}) → Map<String, dynamic>
Serializing metadata, which encapsulates generic data transformations. Custom metadata needs to be converted via the covert callback method.
inherited
serializeNode(ParagraphNode node) → Map<String, dynamic>?
Serialize node data
override
serializeSingleColumnLayoutMetadata(Map<String, dynamic> map) → Map<String, dynamic>
{ "width":213, "padding":-1,0,0,0,0 //-1 is EdgeInsets type , -2 is EdgeInsetsDirectional type. }
inherited
serializeSpans(AttributedSpans spans, {AttributionSerializeBuilder? serializeBuilder}) → List
AttributedSpans(attributions: SpanMarker(attribution: LinkAttribution(url: Uri.parse("www.google.com")), offset: 0, markerType: SpanMarkerType.start), SpanMarker(attribution: LinkAttribution(url: Uri.parse("www.google.com")), offset: 7, markerType: SpanMarkerType.end), )
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited